@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2015 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2015 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2016 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2016 GNU Solidario <health@gnusolidario.org>
 #
 #
 #
@@ -58,7 +58,7 @@ class CreateAppointmentEvaluation(Wizard):
         visit_type = str(app_id.visit_type)
 
         action['pyson_domain'] = PYSONEncoder().encode([
-            ('evaluation_date', '=', appointment),
+            ('appointment', '=', appointment),
             ('patient', '=', patient),
             ('specialty', '=', specialty),
             ('urgency', '=', urgency),
@@ -66,7 +66,7 @@ class CreateAppointmentEvaluation(Wizard):
             ('visit_type', '=', visit_type),
             ])
         action['pyson_context'] = PYSONEncoder().encode({
-            'evaluation_date': appointment,
+            'appointment': appointment,
             'patient': patient,
             'specialty': specialty,
             'urgency': urgency,
